staggR-package: staggR: Fit Difference-in-Differences Models with Staggered...

staggR-packageR Documentation

staggR: Fit Difference-in-Differences Models with Staggered Interventions

Description

Fits linear difference-in-differences models in scenarios where intervention roll-outs are staggered over time. The package implements a version of an approach proposed by Sun and Abraham (2021) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jeconom.2020.09.006")} to estimate cohort- and time-since-treatment specific difference-in-differences parameters, and it provides convenience functions both for specifying the model and for flexibly aggregating coefficients to answer a variety of research questions.

Author(s)

Maintainer: Kyle Hart hartky@ohsu.edu (ORCID) [copyright holder]

Authors:

  • Stephan Lindner

See Also

Useful links:


staggR documentation built on April 2, 2026, 5:08 p.m.