| staggR-package | R Documentation |
Fits linear difference-in-differences models in scenarios where intervention roll-outs are staggered over time. The package implements a version of an approach proposed by Sun and Abraham (2021) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jeconom.2020.09.006")} to estimate cohort- and time-since-treatment specific difference-in-differences parameters, and it provides convenience functions both for specifying the model and for flexibly aggregating coefficients to answer a variety of research questions.
Maintainer: Kyle Hart hartky@ohsu.edu (ORCID) [copyright holder]
Authors:
Stephan Lindner
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.